---
title: <span class="badge object-type-scalar"></span> ElectronVolt
---
# <span class="badge object-type-scalar"></span> ElectronVolt

Energy: Electron volt (eV)

## Definition

```python
# Energy: Electron volt (eV)
ElectronVolt: typing.Literal["ev"] = "ev"
```
